@@ -36,4 +36,4 @@ def start_app(
                 storage_backend=storage_backend,
             )
 
-    app.run(debug=True, host=address, port=port, ssl_context="adhoc")
+    app.run(debug=True, host=address, port=port)
